@@ -1,7 +1,8 @@
 #include <QtGui/QApplication>
 #include <QTranslator>
 #include "urpomainwindow.h"
-#include <QLocale>
+#include <QString>
+#include <cstdlib>
 
 /*! @mainpage Urpo - Unix Remote Printing Operation
 
@@ -23,7 +24,10 @@ int main(int argc, char *argv[])
     QApplication a(argc, argv);
 
     QTranslator appTranslator;
-    appTranslator.load("urpo_" + QLocale::system().name(),":/");
+    // using LANG enviroment variable instead of QLocale because of Qt on Maemo problem
+    // bug #6136
+    QString language = std::getenv("LANG");
+    appTranslator.load("urpo_" + language.toLower() ,":/");
     a.installTranslator(&appTranslator);
 
     UrpoMainWindow w;
